import { Component, ElementRef, EventEmitter, Input, NgModule, Output, Renderer2, SecurityContext } from '@angular/core';
import { DomSanitizer } from '@angular/platform-browser';
import { CommonModule } from '@angular/common';
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/* tslint:disable-next-line */
var hljs = require('highlight.js/lib');
var TdHighlightComponent = /** @class */ (function () {
    /**
     * @param {?} _renderer
     * @param {?} _elementRef
     * @param {?} _domSanitizer
     */
    function TdHighlightComponent(_renderer, _elementRef, _domSanitizer) {
        this._renderer = _renderer;
        this._elementRef = _elementRef;
        this._domSanitizer = _domSanitizer;
        /**
         * lang?: string
         *
         * Language of the code content to be parsed as highlighted html.
         * Defaults to `typescript`
         *
         * e.g. `typescript`, `html` , etc.
         */
        this.language = 'typescript';
        /**
         * contentReady?: function
         * Event emitted after the highlight content rendering is finished.
         */
        this.onContentReady = new EventEmitter();
    }
    Object.defineProperty(TdHighlightComponent.prototype, "content", {
        /**
         * content?: string
         *
         * Code content to be parsed as highlighted html.
         * Used to load data dynamically.
         *
         * e.g. `.html`, `.ts` , etc.
         * @param {?} content
         * @return {?}
         */
        set: function (content) {
            this._content = content;
            this._loadContent(this._content);
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @return {?}
     */
    TdHighlightComponent.prototype.ngAfterViewInit = function () {
        if (!this.language) {
            throw new Error('Error: language attribute must be defined in TdHighlightComponent.');
        }
        if (!this._content) {
            this._loadContent(((this._elementRef.nativeElement)).textContent);
        }
    };
    /**
     * General method to parse a string of code into HTML Elements and load them into the container
     * @param {?} code
     * @return {?}
     */
    TdHighlightComponent.prototype._loadContent = function (code) {
        if (code && code.trim().length > 0) {
            // Clean container
            this._renderer.setProperty(this._elementRef.nativeElement, 'innerHTML', '');
            // Parse html string into actual HTML elements.
            var /** @type {?} */ preElement = this._elementFromString(this._render(code));
        }
        this.onContentReady.emit();
    };
    /**
     * @param {?} codeStr
     * @return {?}
     */
    TdHighlightComponent.prototype._elementFromString = function (codeStr) {
        // Renderer2 doesnt have a parsing method, so we have to sanitize and use [innerHTML]
        // to parse the string into DOM element for now.
        var /** @type {?} */ preElement = this._renderer.createElement('pre');
        this._renderer.appendChild(this._elementRef.nativeElement, preElement);
        var /** @type {?} */ codeElement = this._renderer.createElement('code');
        this._renderer.appendChild(preElement, codeElement);
        // Set .highlight class into <code> element
        this._renderer.addClass(codeElement, 'highlight');
        codeElement.innerHTML = this._domSanitizer.sanitize(SecurityContext.HTML, codeStr);
        return preElement;
    };
    /**
     * @param {?} contents
     * @return {?}
     */
    TdHighlightComponent.prototype._render = function (contents) {
        // Trim leading and trailing newlines
        contents = contents.replace(/^(\s|\t)*\n+/g, '')
            .replace(/(\s|\t)*\n+(\s|\t)*$/g, '');
        // Split markup by line characters
        var /** @type {?} */ lines = contents.split('\n');
        // check how much indentation is used by the first actual code line
        var /** @type {?} */ firstLineWhitespace = lines[0].match(/^(\s|\t)*/)[0];
        // Remove all indentation spaces so code can be parsed correctly
        var /** @type {?} */ startingWhitespaceRegex = new RegExp('^' + firstLineWhitespace);
        lines = lines.map(function (line) {
            return line
                .replace('=""', '') // remove empty values
                .replace(startingWhitespaceRegex, '')
                .replace(/\s+$/, ''); // remove trailing white spaces
        });
        var /** @type {?} */ codeToParse = lines.join('\n')
            .replace(/\{ \{/gi, '{{').replace(/\} \}/gi, '}}')
            .replace(/&lt;/gi, '<').replace(/&gt;/gi, '>'); // replace with < and > to render HTML in angular
        // Parse code with highlight.js depending on language
        var /** @type {?} */ highlightedCode = hljs.highlight(this.language, codeToParse, true);
        highlightedCode.value = highlightedCode.value
            .replace(/=<span class="hljs-value">""<\/span>/gi, '')
            .replace('<head>', '')
            .replace('<head/>', '');
        return highlightedCode.value;
    };
    return TdHighlightComponent;
}());
TdHighlightComponent.decorators = [
    { type: Component, args: [{
                selector: 'td-highlight',
                styles: [":host ::ng-deep {\n  display: block;\n  overflow-x: auto;\n  padding: 16px; }\n  :host ::ng-deep pre,\n  :host ::ng-deep code,\n  :host ::ng-deep .highlight {\n    font-family: Menlo, Monaco, \"Andale Mono\", \"lucida console\", \"Courier New\", monospace; }\n  :host ::ng-deep pre {\n    display: block;\n    overflow-x: auto;\n    padding: 0;\n    margin: 0;\n    background: transparent;\n    font-family: Menlo, Monaco, \"Andale Mono\", \"lucida console\", \"Courier New\", monospace;\n    line-height: 1.45;\n    -moz-tab-size: 2;\n      -o-tab-size: 2;\n         tab-size: 2;\n    -webkit-font-smoothing: auto;\n    -webkit-text-size-adjust: none;\n    position: relative;\n    border-radius: 2px;\n    font-size: 0.8rem; }\n  :host ::ng-deep code {\n    margin: 0;\n    padding: 0;\n    overflow-wrap: break-word;\n    white-space: pre-wrap; }\n  :host ::ng-deep .highlight {\n    display: block;\n    overflow-wrap: break-word;\n    line-height: 1.5;\n    margin: 0; }\n"],
                template: "<ng-content></ng-content>",
            },] },
];
/** @nocollapse */
TdHighlightComponent.ctorParameters = function () { return [
    { type: Renderer2, },
    { type: ElementRef, },
    { type: DomSanitizer, },
]; };
TdHighlightComponent.propDecorators = {
    "content": [{ type: Input, args: ['content',] },],
    "language": [{ type: Input, args: ['lang',] },],
    "onContentReady": [{ type: Output, args: ['contentReady',] },],
};
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var CovalentHighlightModule = /** @class */ (function () {
    function CovalentHighlightModule() {
    }
    return CovalentHighlightModule;
}());
CovalentHighlightModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                ],
                declarations: [
                    TdHighlightComponent,
                ],
                exports: [
                    TdHighlightComponent,
                ],
            },] },
];
/** @nocollapse */
CovalentHighlightModule.ctorParameters = function () { return []; };
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Generated bundle index. Do not edit.
 */
export { TdHighlightComponent, CovalentHighlightModule };
//# sourceMappingURL=covalent-highlight.js.map
